@@ -2,6 +2,14 @@ from django.conf import settings
 """
 define the name that will be used to access the basket from the session.
 """
+
+BASKY_AGE = getattr(
+    settings,
+    'BASKY_AGE',
+    settings.SESSION_COOKIE_AGE
+)
+
+
 BASKY_SESSION_KEY_NAME = getattr(
     settings,
     'BASKY_SESSION_KEY_NAME',
